@@ -1,25 +1,66 @@
+get_xmin_est = function(dat, xmins){
+  row = which.min(dat[,1])
+  ## Check for numerical instabilities
+  ## Can happen in the tails of the LN
+  if(!length(row)) {
+    row = 1L
+    dat[row,] = NA_real_
+    xmins[row] = NA_real_
+    warning("Unable to estimate xmin. This may be due to numerical instabilities. 
+            For example the parameter estimates are in the distribution tails.")
+  }
+  
+  xmin = xmins[row]
+  pars = dat[row, 2:(ncol(dat)-1L)]
+  ntail = dat[row, ncol(dat)]
+  
+  l = list(gof=dat[row, 1], xmin=xmin, pars=pars, ntail=ntail)
+  class(l) = "estimate_xmin"
+  l
+}
+
+get_gof = function(fit_cdf, data_cdf, distance) {
+  if(!(distance %in% c("ks", "reweight")) || length(distance) > 1)
+    stop("Unknown distance measure. The distance parameter should be either ks or reweight")
+  
+  
+  if(distance == "ks")
+    gof = max(abs(data_cdf - fit_cdf))
+  if(distance == "reweight")
+    gof = max(abs(data_cdf - fit_cdf)/sqrt(fit_cdf*(1-fit_cdf)))
+  gof 
+}
+
+#' @rdname get_KS_statistic-deprecated
+#' @title Deprecated function
+#' @description This function is now deprecated and may be removed in future 
+#' versions.
+#' @inheritParams get_distance_statistic
+#' @seealso get_distance_statistic
+#' @export
+get_KS_statistic = function(m, xmax=1e5, distance="ks") {
+  .Deprecated("get_distance_statistic")
+  get_distance_statistic(m, xmax, distance)
+}
+
 #' @rdname estimate_xmin
 #' @export
-get_KS_statistic = function(m, xmax=1e5) {
+get_distance_statistic = function(m, xmax=1e5, distance="ks") {
   if(is(m, "discrete_distribution")) {
     data_cdf = dist_data_all_cdf(m, xmax=xmax)
     fit_cdf = dist_all_cdf(m, xmax=xmax)
   } else {
-    #data_cdf = dist_data_cdf(m, xmax=xmax)
     q = m$dat
-    n = m$internal[["n"]]; N = length(q)
+    n = m$internal[["n"]]
+    N = length(q)
     q = q[(N-n+1):N]
     q = q[q <= xmax]
     fit_cdf = dist_cdf(m, q)
-    
     data_cdf = ((0:(n-1))/n)[1:length(fit_cdf)]
-    #cdf = cdf[1:min(n, xmax)]
   }
-  gof = max(abs(data_cdf - fit_cdf))
-  return(gof)
+  get_gof(fit_cdf, data_cdf, distance)
 }
 
-
 #' Estimating the lower bound (xmin)
 #' 
 #' When fitting heavy tailed distributions, sometimes it 
@@ -36,9 +77,12 @@ get_KS_statistic = function(m, xmax=1e5) {
 #' the bulk of the distribution and cannot calculate the tails to enough
 #' accuracy.}
 #' \item{\code{bootstrap}}{Estimates the unncertainity in the xmin and parameter values via bootstraping.}
-#' \item{\code{bootstrap_p}}{Performs a bootstrapping hypothesis test to determine whether a power law
-#' distribution is plausible. This function only available for power law distribution objects.}}
+#' \item{\code{bootstrap_p}}{Performs a bootstrapping hypothesis test to determine whether a suggested
+#' (typically power law) distribution is plausible. This is only available for distributions that 
+#' have \code{dist_rand} methods available.}}
 #' @param m A reference class object that contains the data.
+#' @param distance A string containing the distance measure (or measures) to calculate. 
+#' Possible values are \code{ks} or \code{reweight}. See details for further information. 
 #' @param pars default \code{NULL}. A vector of parameters used to 
 #' optimise over. 
 #' Otherwise, for each value of \code{xmin}, the mle will be used, i.e. \code{estimate_pars(m)}.
@@ -61,14 +105,15 @@ get_KS_statistic = function(m, xmax=1e5) {
 #' which has a long tail. 
 #' 
 #' To speed up computations for discrete distributions it is sensible to put an 
-#' upper bound, i.e. \code{xmax} or explicitly give values of where to search, i.e. \code{xmin}.
-#' When calculating the kolmogorov-smirnov, the CDF is caculate up to the
-#' maximum value of the data. However, for some data sets and during bootstrapping, very large 
-#' values can be generated. This may cause both speed and memory problems. 
+#' upper bound, i.e. \code{xmax} and/or explicitly give values of where to search, i.e. \code{xmin}.
 #' 
 #' Occassionally bootstrapping can generate strange situations. For example, 
 #' all values in the simulated data set are less then \code{xmin}. In this case, 
-#' the estimated KS statistic will be \code{Inf} and the parameter values, \code{NA}.
+#' the estimated distance measure will be \code{Inf} and the parameter values, \code{NA}.
+#' 
+#' There are other possible distance measures that can be calculated. The default is the
+#' Kolomogorov Smirnoff statistic (\code{KS}). This is equation 3.9 in the CSN paper. The
+#' other measure currently available is \code{reweight}, which is equation 3.11.
 #' @importFrom parallel makeCluster parSapply 
 #' @importFrom parallel clusterExport stopCluster
 #' @note Adapted from Laurent Dubroca's code found at
@@ -94,7 +139,8 @@ get_KS_statistic = function(m, xmax=1e5) {
 #' bootstrap(m, no_of_sims=1, threads=1)
 #' bootstrap_p(m, no_of_sims=1, threads=1)
 #' }
-estimate_xmin = function (m, xmins = NULL, pars=NULL, xmax=1e5) {
+estimate_xmin = function (m, xmins=NULL, pars=NULL, 
+                          xmax=1e5, distance="ks") {
   ## Flag. Go through a bunch of checks to test whether we 
   ## can estimate xmin 
   estimate = length(unique(m$dat)) > 1
@@ -106,7 +152,7 @@ estimate_xmin = function (m, xmins = NULL, pars=NULL, xmax=1e5) {
     if(is.null(xmins))  xmins = unique(m$dat)
     xmins = xmins[xmins <= xmax]
   }
- 
+  
   ## Need to have at least no_pars + 1 data points
   ## to estimate parameters. 
   ## Find (largest - no_pars) data point and subset xmins
@@ -126,7 +172,8 @@ estimate_xmin = function (m, xmins = NULL, pars=NULL, xmax=1e5) {
   if(!estimate || nr < 1) {
     ## Insufficient data to estimate parameters
     dat = matrix(0, nrow=1, ncol=(2 + m$no_pars))
-    dat[1, ] = c(Inf, rep(NA, m$no_pars + 1))
+    dat[1, ] = c(rep(Inf, length(distance)), 
+                 rep(NA, m$no_pars + 1))
     estimate = FALSE
   } else {
     dat = matrix(0, nrow=nr, ncol=(2 + m_cpy$no_pars))   
@@ -145,27 +192,11 @@ estimate_xmin = function (m, xmins = NULL, pars=NULL, xmax=1e5) {
       I = which.max(L)
       m_cpy$pars = m_cpy$pars[I]
     }
-    gof = get_KS_statistic(m_cpy, xmax)
+    gof = get_distance_statistic(m_cpy, xmax, distance)
     dat[xm <- xm + 1L,] = c(gof, m_cpy$pars, get_ntail(m_cpy))
   }
   
-  row = which.min(dat[,1L])
-  ## Check for numerical instabilities
-  ## Can happen in the tails of the LN
-  if(!length(row)) {
-    row = 1L
-    dat[row,] = NA_real_
-    xmins[row] = NA_real_
-    warning("Unable to estimate xmin. This may be due to numerical instabilities. 
-            For example the parameter estimates are in the distribution tails.")
-  }
-  
-  xmin = xmins[row]
-  pars = dat[row, 2:(ncol(dat)-1)]
-  ntail = dat[row, ncol(dat)]
-  
-  l = list(KS=dat[row, 1L], xmin=xmin, pars=pars, ntail=ntail)
-  class(l) = "estimate_xmin"
-  return(l)
+  l = get_xmin_est(dat, xmins)
+  l$distance = distance
+  l
 }
-
