@@ -1,7 +1,7 @@
-test_that("Testing estimate_xmin function", {
-  
+test_that("Testing estimate_xmin accuracy", {
+  skip_on_cran()  
   ##Discrete Power-law
-  load("discrete_data.RData")
+  discrete_data = readRDS("discrete_data.RData")
   mt = displ$new(discrete_data)
   est = estimate_xmin(mt, pars=seq(2, 3, 0.01))
   expect_equal(est$pars, 2.58, tol=1e-1)
@@ -33,11 +33,11 @@ test_that("Testing estimate_xmin function", {
   ##CTN Power-law
   ##Takes a while
   if(interactive()) {
-     load("ctn_data.RData")
+    ctn_data = readRDS("ctn_data.RData")
     mt = conpl$new(ctn_data)
     est = estimate_xmin(mt)
-    expect_equal(est$pars, 2.53255, tol=1e-4)
-    expect_equal(est$xmin, 1.43628, tol=1e-4)
+    expect_equal(est$pars, 2.53255, tol=1e-3)
+    expect_equal(est$xmin, 1.43628, tol=1e-3)
   }
   ##Log-normal
   set.seed(1)
@@ -62,5 +62,36 @@ test_that("Testing estimate_xmin function", {
   
   expect_equal(est$pars, 0.01003, tol=1e-3)
   expect_equal(est$xmin, 4, tol=1e-3)
+ 
+  #########################################
+  ## Edge cases
+  x = c(2, 2,2)
+  mt = displ$new(x)
+  est = estimate_xmin(mt)
+  expect_true(is.infinite(est$gof))
+  expect_true(is.na(est$pars))
+
+  ## Empty object
+  mt = displ$new()
+  est = estimate_xmin(mt)
+  expect_true(is.infinite(est$gof))
+  expect_true(is.na(est$pars))
+
 }
-)
\ No newline at end of file
+)
+
+test_that("Testing estimate_xmin distance measures", {
+  skip_on_cran() 
+  discrete_data = 1:10
+  mt = displ$new(discrete_data)
+  est = estimate_xmin(mt, pars=seq(2, 3, 0.01), distance="ks")
+  expect_equal(est$pars, 3, tol=1e-1)
+  expect_equal(est$xmin, 5, tol=1e-3)
+
+  est = estimate_xmin(mt, pars=seq(2, 3, 0.01), distance="reweight")
+  expect_equal(est$pars, 2.57, tol=1e-1)
+  expect_equal(est$xmin, 4, tol=1e-3)
+  
+}
+)
+
